# Classy-Json ![PYPI Downloads](https://img.shields.io/pypi/dw/classy-json?color=64b594)
### An attempt at recreating the way json works in JavaScript, but in the Python programming language.

## Setup / Install
### Using pip:
```
python3 -m pip install Classy-Json
```
### Manually:
* Clone the repository
```
git clone https://github.com/Iapetus-11/Classy-Json.git
```
* cd into the directory
```
cd Classy-Json
```
* Run setup.py
```
python3 setup.py build install
```

## Contribution
* Fork the repository
* Make any changes
* Submit a pull request
